:code:`agox graph-sort`
===================

.. note:: 

   The most up to date help for :code:`agox graph-sort` is available through `agox graph-sort --help`.

Reduce the number of structures by only selecting those with unique graphs. 

.. code-block:: console

    agox graph-sort -t trajectory.traj

